<?php
namespace Ak\Wp\Init;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;

/**
 * Class Boot
 *
 * @package Ak\Wp\Init
 */
final class Boot implements MiddlewareInterface
{
    /**
     * Process an incoming server request and return a response, optionally delegating
     * response creation to a handler.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        // Set up current user.
        $GLOBALS['wp']->init();

        /**
         * Fires after WordPress has finished loading but before any headers are sent.
         *
         * Most of WP is loaded at this stage, and the user is authenticated. WP continues
         * to load on the {@see 'init'} hook that follows (e.g. widgets), and many plugins instantiate
         * themselves on it for all sorts of reasons (e.g. they need a user, a taxonomy, etc.).
         *
         * If you wish to plug an action once WP is loaded, use the {@see 'wp_loaded'} hook below.
         *
         * @since 1.5.0
         */
        do_action('init');

        /**
         * This hook is fired once WP, all plugins, and the theme are fully loaded and instantiated.
         *
         * Ajax requests should use wp-admin/admin-ajax.php. admin-ajax.php can handle requests for
         * users not logged in.
         *
         * @link https://codex.wordpress.org/AJAX_in_Plugins
         *
         * @since 3.0.0
         */
        do_action('wp_loaded');

        return $handler->handle($request);
    }
}