<?php
namespace Ak\Wp\Init;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;

/**
 * Class Includes
 *
 * @package Ak\Wp\Init
 */
final class Includes implements MiddlewareInterface
{
    /**
     * Process an incoming server request and return a response, optionally delegating
     * response creation to a handler.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        if (!defined('WPINC')) {
            define('WPINC', 'wp-includes');
        }

        /*
         * These can't be directly globalized in version.php. When updating,
         * we're including version.php from another installation and don't want
         * these values to be overridden if already set.
         */
        /** @noinspection PhpUnusedLocalVariableInspection */
        global $wp_version, $wp_db_version, $tinymce_version, $required_php_version, $required_mysql_version, $wp_local_package;
        require( ABSPATH . WPINC . '/version.php' );

        require_once ABSPATH . '/wp-includes/admin-bar.php';
        require_once ABSPATH . '/wp-includes/author-template.php';
        require_once ABSPATH . '/wp-includes/cache.php';
        require_once ABSPATH . '/wp-includes/capabilities.php';
        require_once ABSPATH . '/wp-includes/category.php';
        require_once ABSPATH . '/wp-includes/category-template.php';
        require_once ABSPATH . '/wp-includes/comment.php';
        require_once ABSPATH . '/wp-includes/comment-template.php';
        require_once ABSPATH . '/wp-includes/cron.php';
        require_once ABSPATH . '/wp-includes/default-constants.php';
        require_once ABSPATH . '/wp-includes/formatting.php';
        require_once ABSPATH . '/wp-includes/functions.php';
        require_once ABSPATH . '/wp-includes/general-template.php';
        require_once ABSPATH . '/wp-includes/kses.php';
        require_once ABSPATH . '/wp-includes/http.php';
        require_once ABSPATH . '/wp-includes/l10n.php';
        require_once ABSPATH . '/wp-includes/link-template.php';
        require_once ABSPATH . '/wp-includes/meta.php';
        require_once ABSPATH . '/wp-includes/nav-menu.php';
        require_once ABSPATH . '/wp-includes/plugin.php';
        require_once ABSPATH . '/wp-includes/post.php';
        require_once ABSPATH . '/wp-includes/post-formats.php';
        require_once ABSPATH . '/wp-includes/post-template.php';
        require_once ABSPATH . '/wp-includes/post-thumbnail-template.php';
        require_once ABSPATH . '/wp-includes/query.php';
        require_once ABSPATH . '/wp-includes/rewrite.php';
        require_once ABSPATH . '/wp-includes/script-loader.php';
        require_once ABSPATH . '/wp-includes/shortcodes.php';
        require_once ABSPATH . '/wp-includes/taxonomy.php';
        require_once ABSPATH . '/wp-includes/theme.php';
        require_once ABSPATH . '/wp-includes/template.php';
        require_once ABSPATH . '/wp-includes/update.php';
        require_once ABSPATH . '/wp-includes/user.php';
        require_once ABSPATH . '/wp-includes/widgets.php';

        require_once ABSPATH . '/wp-includes/media.php';

        require_once ABSPATH . '/wp-includes/rest-api.php';

        wp_initial_constants();

        return $handler->handle($request);
    }
}