<?php
namespace Ak\Wp\Init;

use Ak\Wp\Shortcode\ShortcodeLoader;
use Psr\Container\ContainerInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;

/**
 * Class Theme
 *
 * @package Ak\Wp\Init
 */
final class Theme implements MiddlewareInterface
{
    /**
     * Process an incoming server request and return a response, optionally delegating
     * response creation to a handler.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        /** @var ContainerInterface $container */
        $container = $request->getAttribute('container');
        /** @var ShortcodeLoader $loader */
        $loader = $container->get(ShortcodeLoader::class);
        $loader->register();

        define('WP_DEFAULT_THEME', 'flatsome');

        /** @noinspection PhpUnusedLocalVariableInspection */
        global $_ux_builder_breakpoints, $_ux_builder_breakpoints_default, $nav_elements;
        $GLOBALS['nav_elements'] = [];

        /**
         * Fires before the theme is loaded.
         *
         * @since 2.6.0
         */
        do_action('setup_theme');

        // Define the template related constants.
        wp_templating_constants();

        // Load the functions for the active theme, for both parent and child theme if applicable.
        if (!wp_installing()) {
            if (TEMPLATEPATH !== STYLESHEETPATH && file_exists(STYLESHEETPATH . '/functions.php')) {
                /** @noinspection PhpIncludeInspection */
                include STYLESHEETPATH . '/functions.php';
            }

            if (file_exists(TEMPLATEPATH . '/functions.php')) {
                /** @noinspection PhpIncludeInspection */
                include TEMPLATEPATH . '/functions.php';
            }
        }

        /**
         * Fires after the theme is loaded.
         *
         * @since 3.0.0
         */
        do_action('after_setup_theme');

        remove_action('wp_enqueue_scripts', 'flatsome_countdown_shortcode_scripts');
        remove_action('wp_enqueue_scripts', 'flatsome_live_search_script');

        return $handler->handle($request);
    }
}