<?php
namespace Ak\Wp\Shortcode;

use Laminas\ServiceManager\PluginManagerInterface;

/**
 * Plugin koji registrira sve dodane shortcodeove.
 *
 * @package Ak\Wp\Shortcode
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/wp-shortcode
 */
final class ShortcodeLoader
{
    /** @var string[] */
    private $tags;
    /** @var PluginManagerInterface */
    private $shortcodeManager;
    /** @var ShortcodeInterface[] */
    private $loaded = [];

    /**
     * ShortcodeLoader constructor.
     * @param string[] $tags
     * @param PluginManagerInterface $shortcodeManager
     */
    public function __construct(array $tags, PluginManagerInterface $shortcodeManager)
    {
        $this->tags = $tags;
        $this->shortcodeManager = $shortcodeManager;
    }

    /**
     * Dodaje akcije i filtere u WordPress.
     */
    public function register(): void
    {
        add_action('after_setup_theme', [$this, 'attachShortcodes']);
    }

    /**
     * Inicijalizira shortcode-ove.
     */
    public function attachShortcodes(): void
    {
        foreach ($this->tags as $tag) {
            if (isset($this->loaded[$tag])) {
                continue;
            }

            /** @var ShortcodeInterface $shortcode */
            $shortcode = $this->shortcodeManager->get($tag);

            if (shortcode_exists($tag)) {
                remove_shortcode($tag);
            }

            add_shortcode($tag, [$shortcode, 'render']);
            $this->loaded[$tag] = $shortcode;
        }
    }
}
